@@ -23,7 +23,7 @@ def install():
 
 def check_fish_version():
     """Display a warning if the minimum Fish version is not installed. Bail silently if
-       the 'packaging' module is missing or if Fish is not installed."""
+    the 'packaging' module is missing or if Fish is not installed."""
     try:
         import subprocess
         from packaging import version
@@ -34,8 +34,11 @@ def check_fish_version():
         fish_version = fish_version.partition("-")[0]
         if version.parse(fish_version) < version.parse(minimum_fish_version):
             log.warning(
-                "{}WARNING: VirtualFish requires Fish {} or higher. Current version: {}{}".format(
-                vcolors.RED, minimum_fish_version, fish_version, vcolors.NORMAL))
+                """{}WARNING: VirtualFish requires Fish {} or higher.
+                   Current version: {}{}""".format(
+                    vcolors.RED, minimum_fish_version, fish_version, vcolors.NORMAL
+                )
+            )
     except (ModuleNotFoundError, FileNotFoundError):
         pass
 
@@ -61,8 +64,11 @@ def main():
                 "load it."
             )
         else:
-            print("VirtualFish isn't compatible with {}, only Fish {}+.".format(
-                the_shell, minimum_fish_version))
+            print(
+                "VirtualFish isn't compatible with {}, only Fish {}+.".format(
+                    the_shell, minimum_fish_version
+                )
+            )
 
 
 if __name__ == "__main__":
